@@ -20,13 +20,14 @@ public:
     virtual void sendState() = 0;
     virtual void setPosition(double azimuth, double elevation) = 0;
     virtual void stopTimers() = 0;
+    double normalizeAzimuth(double azimuth) const;
 
 signals:
     void rotIsReady();
     void positioningChanged(double azimuth, double elevation);
 
     // Error Signal
-    void errorOccured(QString, QString);
+    void errorOccurred(QString, QString);
 
 protected:
     RotProfile rotProfile;
