@@ -299,34 +299,34 @@ void QRZCallbook::processReply(QNetworkReply* reply)
                 incorrectLogin = false;
 
             if      (elementName == "Key")       sessionId = xml.readElementText();
-            else if (elementName == "call")      resposeData.call = xml.readElementText().toUpper();
-            else if (elementName == "dxcc")      resposeData.dxcc = xml.readElementText();
-            else if (elementName == "fname")     resposeData.fname = xml.readElementText();
-            else if (elementName == "name")      resposeData.lname = xml.readElementText();
-            else if (elementName == "addr1")     resposeData.addr1 = xml.readElementText();
-            else if (elementName == "addr2")     resposeData.qth = xml.readElementText();
-            else if (elementName == "state")     resposeData.us_state = xml.readElementText();
-            else if (elementName == "zip")       resposeData.zipcode = xml.readElementText();
-            else if (elementName == "country")   resposeData.country = xml.readElementText();
-            else if (elementName == "lat")       resposeData.latitude = xml.readElementText();
-            else if (elementName == "lon")       resposeData.longitude = xml.readElementText();
-            else if (elementName == "county")    resposeData.county = xml.readElementText();
-            else if (elementName == "grid")      resposeData.gridsquare = xml.readElementText().toUpper();
-            else if (elementName == "efdate")    resposeData.lic_year = xml.readElementText();
-            else if (elementName == "qslmgr")    resposeData.qsl_via = xml.readElementText();
-            else if (elementName == "email")     resposeData.email = xml.readElementText();
-            else if (elementName == "GMTOffset") resposeData.utc_offset = xml.readElementText();
+            else if (elementName == "call")      resposeData.call = decodeHtmlEntities(xml.readElementText().toUpper());
+            else if (elementName == "dxcc")      resposeData.dxcc = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "fname")     resposeData.fname = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "name")      resposeData.lname = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "addr1")     resposeData.addr1 = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "addr2")     resposeData.qth = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "state")     resposeData.us_state = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "zip")       resposeData.zipcode = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "country")   resposeData.country = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "lat")       resposeData.latitude = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "lon")       resposeData.longitude = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "county")    resposeData.county = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "grid")      resposeData.gridsquare = decodeHtmlEntities(xml.readElementText().toUpper());
+            else if (elementName == "efdate")    resposeData.lic_year = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "qslmgr")    resposeData.qsl_via = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "email")     resposeData.email = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "GMTOffset") resposeData.utc_offset = decodeHtmlEntities(xml.readElementText());
             else if (elementName == "eqsl")      resposeData.eqsl = (xml.readElementText() == "1") ? "Y" : "N";
-            else if (elementName == "mqsl")      resposeData.pqsl = xml.readElementText();
-            else if (elementName == "cqzone")    resposeData.cqz = xml.readElementText();
-            else if (elementName == "ituzone")   resposeData.ituz = xml.readElementText();
-            else if (elementName == "born")      resposeData.born = xml.readElementText();
+            else if (elementName == "mqsl")      resposeData.pqsl = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "cqzone")    resposeData.cqz = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "ituzone")   resposeData.ituz = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "born")      resposeData.born = decodeHtmlEntities(xml.readElementText());
             else if (elementName == "lotw")      resposeData.lotw = (xml.readElementText() == "1") ? "Y" : "N";
-            else if (elementName == "iota")      resposeData.iota = xml.readElementText();
-            else if (elementName == "nickname")  resposeData.nick = xml.readElementText();
-            else if (elementName == "url")       resposeData.url = xml.readElementText();
-            else if (elementName == "name_fmt")  resposeData.name_fmt = xml.readElementText();
-            else if (elementName == "image")     resposeData.image_url = xml.readElementText();
+            else if (elementName == "iota")      resposeData.iota = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "nickname")  resposeData.nick = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "url")       resposeData.url = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "name_fmt")  resposeData.name_fmt = decodeHtmlEntities(xml.readElementText());
+            else if (elementName == "image")     resposeData.image_url = decodeHtmlEntities(xml.readElementText());
         }
 
         if (!resposeData.call.isEmpty())
@@ -512,14 +512,14 @@ void QRZUploader::processReply(QNetworkReply *reply)
     reply->deleteLater();
 }
 
-QMap<QString, QString> QRZUploader::parseActionResponse(const QString &reponseString) const
+QMap<QString, QString> QRZUploader::parseActionResponse(const QString &responseString) const
 {
     FCT_IDENTIFICATION;
 
-    qCDebug(function_parameters) << reponseString;
+    qCDebug(function_parameters) << responseString;
 
     QMap<QString, QString> data;
-    const QStringList &parsedResponse = reponseString.split("&");
+    const QStringList &parsedResponse = responseString.split("&");
 
     for ( const QString &param : parsedResponse )
     {
