@@ -85,6 +85,8 @@ void AwardsDialog::refreshTable(int)
     QStringList addlCTEs;
     QStringList stmt_total_band_condition_work;
     QStringList stmt_total_band_condition_confirmed;
+    QStringList stmt_not_confirmed;
+    QStringList stmt_any_worked;
 
     const QString &awardSelected = getSelectedAward();
 
@@ -121,6 +123,8 @@ void AwardsDialog::refreshTable(int)
         stmt_having << QString("SUM(d.'%1') = 0").arg(band.name);
         stmt_total_band_condition_work << QString("e.'%0' > 0").arg(band.name);
         stmt_total_band_condition_confirmed << QString("e.'%0' > 1").arg(band.name);
+        stmt_not_confirmed << QString("MAX(d.'%1') < 2").arg(band.name);
+        stmt_any_worked << QString("MAX(d.'%1') > 0").arg(band.name);
     }
 
     stmt_max_part << QString(" MAX(CASE WHEN prop_mode = 'SAT' AND m.dxcc IN (%1) THEN %2 ELSE 0 END) as 'SAT' ").arg(modes.join(","), innerConfirmedCase)
@@ -139,6 +143,10 @@ void AwardsDialog::refreshTable(int)
                                    << "e.'EME' > 0";
     stmt_total_band_condition_confirmed << "e.'SAT' > 1"
                                         << "e.'EME' > 1";
+    stmt_not_confirmed << " MAX(d.'SAT') < 2"
+                       << " MAX(d.'EME') < 2";
+    stmt_any_worked << " MAX(d.'SAT') > 0"
+                    << " MAX(d.'EME') > 0";
 
     sourceContactsTable = " source_contacts AS ("
                           "  SELECT * "
@@ -150,11 +158,12 @@ void AwardsDialog::refreshTable(int)
         setNotWorkedEnabled(true);
         const QString &entitySelected = getSelectedEntity();
         headersColumns = "translate_to_locale(d.name) col1, d.prefix col2 ";
-        sqlPartDetailTable = " FROM (SELECT id, name, prefix FROM dxcc_entities "
-                             "       UNION SELECT DISTINCT dxcc, dxcc, '" + tr("Unknown") + "' as prefix FROM source_contacts a LEFT JOIN dxcc_entities b ON a.dxcc = b.id WHERE b.id IS NULL) d "
-                             "   LEFT OUTER JOIN source_contacts c ON d.id = c.dxcc"
-                             "   LEFT OUTER JOIN modes m on c.mode = m.name"
-                             " WHERE (c.id is NULL or c.my_dxcc = '" + entitySelected + "') ";
+        sqlPartDetailTable = " FROM (SELECT id, name, prefix FROM dxcc_entities_clublog WHERE deleted = 0 "
+                             "       UNION "
+                             "       SELECT DISTINCT dxcc, b.name, b.prefix || ' (" + tr("DELETED") + ")' "
+                             "             FROM source_contacts a INNER JOIN dxcc_entities_clublog b ON a.dxcc = b.id AND b.deleted = 1 where a.my_dxcc = '" + entitySelected + "') d "
+                             "   LEFT OUTER JOIN source_contacts c ON (d.id = c.dxcc AND (c.id IS NULL OR c.my_dxcc = '" + entitySelected + "'))"
+                             "   LEFT OUTER JOIN modes m on c.mode = m.name ";
         addWherePart = " AND (c.id is NULL OR c.my_dxcc = '" + entitySelected + "') ";
     }
     else if ( awardSelected == "waz" )
@@ -336,6 +345,17 @@ void AwardsDialog::refreshTable(int)
                           "     INNER JOIN modes m on c.mode = m.name ";
     }
 
+    QStringList havingConditions;
+    if ( ui->notWorkedCheckBox->isChecked() )
+        havingConditions << QString("(%1)").arg(stmt_having.join(" AND "));
+    if ( ui->notConfirmedCheckBox->isChecked() )
+        havingConditions << QString("(%1) AND (%2)").arg(stmt_not_confirmed.join(" AND "),
+                                                         stmt_any_worked.join(" OR "));
+
+    QString havingClause;
+    if ( !havingConditions.isEmpty() )
+        havingClause = QString("HAVING %1").arg(havingConditions.join(" OR "));
+
     addlCTEs.append(sourceContactsTable);
 
     QString finalSQL(QString(
@@ -400,7 +420,7 @@ void AwardsDialog::refreshTable(int)
                                                            tr("Worked")).arg(  // 14
                                                            stmt_sum_worked.join(","), // 15
                                                            stmt_sum_total.join(","), // 16
-                                                           ui->notWorkedCheckBox->isChecked() ? QString("HAVING %1").arg(stmt_having.join(" AND ")) : QString()) // 17
+                                                           havingClause) // 17
                                                            );
     qDebug(runtime) << finalSQL;
 
@@ -518,4 +538,8 @@ void AwardsDialog::setNotWorkedEnabled(bool enabled)
     ui->notWorkedLabel->setVisible(enabled);
     ui->notWorkedCheckBox->setChecked(enabled && ui->notWorkedCheckBox->isChecked());
     ui->notWorkedCheckBox->blockSignals(false);
+    ui->notConfirmedCheckBox->blockSignals(true);
+    ui->notConfirmedCheckBox->setVisible(enabled);
+    ui->notConfirmedCheckBox->setChecked(enabled && ui->notConfirmedCheckBox->isChecked());
+    ui->notConfirmedCheckBox->blockSignals(false);
 }
