@@ -170,6 +170,7 @@ LogbookWidget::LogbookWidget(QWidget *parent) :
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_DCL_QSL_RCVD, new ComboFormatDelegate(Data::instance()->qslRcvdEnum, ui->contactTable));
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_DCL_QSL_SENT, new ComboFormatDelegate(Data::instance()->qslSentEnum, ui->contactTable));
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_DISTANCE, new DistanceFormatDelegate(1, 0.1, ui->contactTable));
+    ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_EQSL_AG, new ComboFormatDelegate(Data::instance()->eqslAgEnum, ui->contactTable));
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_EQSL_QSLRDATE, new DateFormatDelegate(ui->contactTable));
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_EQSL_QSLSDATE, new DateFormatDelegate(ui->contactTable));
     ui->contactTable->setItemDelegateForColumn(LogbookModel::COLUMN_EQSL_QSL_RCVD, new ComboFormatDelegate(Data::instance()->qslRcvdEnum, ui->contactTable));
@@ -264,7 +265,7 @@ LogbookWidget::LogbookWidget(QWidget *parent) :
 
     ui->countrySelectFilter->blockSignals(true);
     ui->countrySelectFilter->setModel(new SqlListModel("SELECT id, translate_to_locale(name) "
-                                                       "FROM dxcc_entities WHERE id IN (SELECT DISTINCT dxcc FROM contacts) "
+                                                       "FROM dxcc_entities_clublog WHERE id IN (SELECT DISTINCT dxcc FROM contacts) "
                                                        "ORDER BY 2 COLLATE LOCALEAWARE ASC;",
                                                        tr("All Countries"),
                                                        ui->countrySelectFilter));
@@ -600,6 +601,10 @@ void LogbookWidget::filterCallsign(const QString &call)
         ui->searchTextFilter->blockSignals(true);
         ui->searchTextFilter->setText(call);
         ui->searchTextFilter->blockSignals(false);
+        // clearbutton is shown only when signals are enabled. therefore
+        // it is needed to force clear-button update
+        ui->searchTextFilter->setClearButtonEnabled(false);
+        ui->searchTextFilter->setClearButtonEnabled(true);
     }
 
     filterTable();
