@@ -2,6 +2,10 @@
 #include <QLabel>
 #include <QColor>
 #include <QSpacerItem>
+#include <QShortcut>
+#include <QDesktopServices>
+#include <QStyleHints>
+
 #include "MainWindow.h"
 #include "ui_MainWindow.h"
 #include "ui/SettingsDialog.h"
@@ -50,19 +54,29 @@ MainWindow::MainWindow(QWidget* parent) :
 
     PotaQE::instance();
 
-    darkLightModeSwith = new SwitchButton("", ui->statusBar);
-    darkIconLabel = new QLabel("<html><img src=':/icons/light-dark-24px.svg'></html>",ui->statusBar);
+    themeButton = new QPushButton(this);
+    themeButton->setToolTip(tr("Color Theme"));
+    themeButton->setIcon(QIcon(QPixmap(":/icons/color-palette-dark.svg")));
+    themeButton->setFlat(true);
+
+    QMenu *themeMenu = new QMenu(this);
+    themeMenu->addAction(ui->actionThemeNative);
+    themeMenu->addAction(ui->actionThemeLight);
+    themeMenu->addAction(ui->actionThemeDark);
+    QActionGroup *themeGroup = new QActionGroup(this);
+    themeGroup->addAction(ui->actionThemeNative);
+    themeGroup->addAction(ui->actionThemeLight);
+    themeGroup->addAction(ui->actionThemeDark);
+
+    themeButton->setMenu(themeMenu);
 
     /* Dark Mode is supported only in case of Fusion Style */
     if ( QApplication::style()->objectName().compare("fusion",
                                                      Qt::CaseSensitivity::CaseInsensitive) != 0)
     {
         isFusionStyle = false;
-        darkLightModeSwith->setEnabled(false);
-        darkIconLabel->setEnabled(false);
-        darkLightModeSwith->setToolTip(tr("Not enabled for non-Fusion style"));
-        darkModeToggle(Qt::Unchecked);
-
+        themeButton->setEnabled(false);
+        themeButton->setToolTip(tr("Not enabled for non-Fusion style"));
     }
     else
     {
@@ -147,8 +161,7 @@ MainWindow::MainWindow(QWidget* parent) :
 
     ui->statusBar->addPermanentWidget(alertTextButton);
     ui->statusBar->addPermanentWidget(alertButton);
-    ui->statusBar->addPermanentWidget(darkLightModeSwith);
-    ui->statusBar->addPermanentWidget(darkIconLabel);
+    ui->statusBar->addPermanentWidget(themeButton);
 
     setContestMode(LogParam::getContestID());
 
@@ -198,8 +211,15 @@ MainWindow::MainWindow(QWidget* parent) :
     connect(this, &MainWindow::themeChanged, ui->rotatorWidget, &RotatorWidget::redrawMap);
     connect(this, &MainWindow::themeChanged, stats, &StatisticsWidget::changeTheme);
 
-    connect(darkLightModeSwith, &SwitchButton::stateChanged, this, &MainWindow::darkModeToggle);
-    darkLightModeSwith->setChecked(LogParam::getMainWindowDarkMode());
+    connect(ui->actionThemeNative, &QAction::triggered, this, [this]() {
+        this->themeInit(0);
+    });
+    connect(ui->actionThemeDark, &QAction::triggered, this, [this]() {
+        this->themeInit(1);
+    });
+    connect(ui->actionThemeLight, &QAction::triggered, this, [this]() {
+        this->themeInit(2);
+    });
 
     connect(Rig::instance(), &Rig::rigErrorPresent, this, &MainWindow::rigErrorHandler);
     connect(Rig::instance(), &Rig::rigCWKeyOpenRequest, this, &MainWindow::cwKeyerConnectProfile);
@@ -552,7 +572,8 @@ QStringList MainWindow::getBuiltInStaticShortcutList() const
     const QList<QShortcut*> allShortcuts = findChildren<QShortcut*>();
     for ( QShortcut* shortcut : allShortcuts)
     {
-        if ( !shortcut->key().toString().isEmpty() )
+        if (!shortcut->key().toString().isEmpty())
+
         {
             qCDebug(runtime) << "Built-In nonchangeble shortcut"
                              << shortcut->key().toString(QKeySequence::NativeText);
@@ -831,26 +852,126 @@ void MainWindow::showUpdateDialog(const QString &newVersion, const QString &repo
         settings.setValue("seenversion", newVersion); // platform-depend parameter
 }
 
-void MainWindow::darkModeToggle(int mode)
+void MainWindow::setDarkTheme()
 {
     FCT_IDENTIFICATION;
 
-    qCDebug(function_parameters) << mode;
+    QPalette darkPalette;
+    QColor darkColor = QColor(45, 45, 45);
+    QColor disabledColor = QColor(127, 127, 127);
+    darkPalette.setColor(QPalette::Window, darkColor);
+    darkPalette.setColor(QPalette::WindowText, Qt::white);
+    darkPalette.setColor(QPalette::Base, QColor(18, 18, 18));
+    darkPalette.setColor(QPalette::Disabled, QPalette::Base, darkColor);
+    darkPalette.setColor(QPalette::AlternateBase, darkColor);
+    darkPalette.setColor(QPalette::Text, Qt::white);
+    darkPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
+    darkPalette.setColor(QPalette::Button, darkColor);
+    darkPalette.setColor(QPalette::ButtonText, Qt::white);
+    darkPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
+    darkPalette.setColor(QPalette::BrightText, Qt::red);
+    darkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
+    darkPalette.setColor(QPalette::Highlight, QColor(42, 130, 218));
+    darkPalette.setColor(QPalette::HighlightedText, Qt::black);
+    darkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, disabledColor);
 
-    bool darkMode = (mode == Qt::Checked) ? true: false;
-    LogParam::setMainWindowDarkMode(darkMode);
+    qApp->setPalette(darkPalette);
+}
 
-    if ( mode == Qt::Checked)
-        setDarkMode();
-    else
-        setLightMode();
+void MainWindow::setLightTheme()
+{
+    FCT_IDENTIFICATION;
+
+    QPalette lightPalette;
+    QColor lightColor = QColor(239, 239, 239);
+    QColor disabledColor = QColor(190, 190, 190);
+    lightPalette.setColor(QPalette::Window, lightColor);
+    lightPalette.setColor(QPalette::WindowText, Qt::black);
+    lightPalette.setColor(QPalette::Base, Qt::white);
+    lightPalette.setColor(QPalette::Disabled, QPalette::Base, lightColor);
+    lightPalette.setColor(QPalette::AlternateBase, lightColor);
+    lightPalette.setColor(QPalette::Text, Qt::black);
+    lightPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
+    lightPalette.setColor(QPalette::Button, lightColor);
+    lightPalette.setColor(QPalette::ButtonText, Qt::black);
+    lightPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
+    lightPalette.setColor(QPalette::BrightText, Qt::white);
+    lightPalette.setColor(QPalette::Link, QColor(0, 0, 255));
+    lightPalette.setColor(QPalette::Highlight, QColor(48, 140, 198));
+    lightPalette.setColor(QPalette::HighlightedText, Qt::white);
+    lightPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, Qt::white);
+
+    qApp->setPalette(lightPalette);
+
+}
+
+bool MainWindow::setNativeTheme()
+{
+    FCT_IDENTIFICATION;
+
+    qApp->setPalette(this->style()->standardPalette());
+    bool isDark = false;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+    const auto scheme = QGuiApplication::styleHints()->colorScheme();
+    isDark = scheme == Qt::ColorScheme::Dark;
+#else
+    const QPalette defaultPalette = this->style()->standardPalette();
+    const auto text = defaultPalette.color(QPalette::WindowText);
+    const auto window = defaultPalette.color(QPalette::Window);
+    isDark = text.lightness() > window.lightness();
+#endif // QT_VERSION
+
+    return isDark;
+}
+
+void MainWindow::themeInit(int mode)
+{
+    FCT_IDENTIFICATION;
+
+    LogParam::setMainWindowDarkMode(mode);
+
+    bool isDark = false;
+    switch (mode) {
+    case 0:
+        ui->actionThemeNative->setChecked(true);
+        isDark = this->setNativeTheme();
+        break;
+    case 1:
+        ui->actionThemeDark->setChecked(true);
+        this->setDarkTheme();
+        isDark = true;
+        break;
+    case 2:
+        ui->actionThemeLight->setChecked(true);
+        this->setLightTheme();
+        break;
+    default:
+        qWarning() << "Unsupported theme ID" << mode;
+    }
 
     QFile style(":/res/stylesheet.css");
     style.open(QFile::ReadOnly | QIODevice::Text);
     qApp->setStyleSheet(style.readAll());
     style.close();
 
-    emit themeChanged(darkMode);
+    if (isDark) {
+        themeButton->setIcon(QIcon(QPixmap(":/icons/color-palette-dark.svg")));
+    } else {
+        themeButton->setIcon(QIcon(QPixmap(":/icons/color-palette-light.svg")));
+    }
+
+    emit themeChanged(mode, isDark);
+}
+
+void MainWindow::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::ThemeChange) {
+        if (ui->actionThemeNative->isChecked()) {
+            this->themeInit(0);
+        }
+    }
+    QMainWindow::changeEvent(event);
 }
 
 void MainWindow::processSpotAlert(SpotAlert alert)
@@ -951,9 +1072,12 @@ void MainWindow::setLayoutGeometry()
 
     QByteArray newGeometry;
     QByteArray newState;
-    bool darkMode = false;
-    const QList<QPair<QString, QString>> bandmapWidgets = (layoutProfile.profileName.isEmpty()) ? MainLayoutProfilesManager::toPairStringList(LogParam::getMainWindowBandmapWidgets())
-                                                                                                : layoutProfile.addlBandmaps;
+    int darkMode = 0;
+    const QList<QPair<QString, QString>> bandmapWidgets
+        = (layoutProfile.profileName.isEmpty())
+              ? MainLayoutProfilesManager::toPairStringList(LogParam::getMainWindowBandmapWidgets())
+              : layoutProfile.addlBandmaps;
+
     if ( layoutProfile.mainGeometry != QByteArray()
         || layoutProfile.mainState != QByteArray() )
     {
@@ -986,7 +1110,7 @@ void MainWindow::setLayoutGeometry()
     connect(nt, &QTimer::timeout, this, [this, darkMode, newState]()
     {
         restoreState(newState);
-        darkLightModeSwith->setChecked(isFusionStyle && darkMode);
+        this->themeInit(isFusionStyle ? darkMode : 0);
         connect(MainLayoutProfilesManager::instance(), &MainLayoutProfilesManager::profileChanged,
                 this, &MainWindow::setSimplyLayoutGeometry);
     });
@@ -1027,7 +1151,7 @@ void MainWindow::setSimplyLayoutGeometry()
         connect(nt, &QTimer::timeout, this, [this, layoutProfile]()
         {
             restoreState(layoutProfile.mainState);
-            darkLightModeSwith->setChecked(isFusionStyle && layoutProfile.darkMode);
+            this->themeInit(isFusionStyle ? layoutProfile.darkMode : 0);            
         });
         nt->connect(nt, &QTimer::timeout, nt, &QTimer::deleteLater);
         nt->start();
@@ -1045,8 +1169,13 @@ void MainWindow::saveProfileLayoutGeometry()
         layoutProfile.addlBandmaps = getNonVfoBandmapsParams();
         layoutProfile.mainGeometry = saveGeometry();
         layoutProfile.mainState = saveState();
-        layoutProfile.darkMode = darkLightModeSwith->isChecked();
-        layoutProfile.tabsexpanded =  ui->newContactWidget->getTabCollapseState();
+        layoutProfile.darkMode = 0;
+        if (ui->actionThemeDark->isChecked()) {
+            layoutProfile.darkMode = 1;
+        } else if (ui->actionThemeLight->isChecked()) {
+            layoutProfile.darkMode = 2;
+        }
+        layoutProfile.tabsexpanded = ui->newContactWidget->getTabCollapseState();
         MainLayoutProfilesManager::instance()->addProfile(layoutProfile.profileName, layoutProfile);
         MainLayoutProfilesManager::instance()->blockSignals(true); // prevent screen flashing
         MainLayoutProfilesManager::instance()->save();
@@ -1063,40 +1192,6 @@ void MainWindow::setEquipmentKeepOptions(bool)
     //saveEquipmentConnOptions();
 }
 
-
-
-void MainWindow::setDarkMode()
-{
-    FCT_IDENTIFICATION;
-
-    QPalette darkPalette;
-    QColor darkColor = QColor(45,45,45);
-    QColor disabledColor = QColor(127,127,127);
-    darkPalette.setColor(QPalette::Window, darkColor);
-    darkPalette.setColor(QPalette::WindowText, Qt::white);
-    darkPalette.setColor(QPalette::Base, QColor(18,18,18));
-    darkPalette.setColor(QPalette::AlternateBase, darkColor);
-    darkPalette.setColor(QPalette::Text, Qt::white);
-    darkPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
-    darkPalette.setColor(QPalette::Button, darkColor);
-    darkPalette.setColor(QPalette::ButtonText, Qt::white);
-    darkPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
-    darkPalette.setColor(QPalette::BrightText, Qt::red);
-    darkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
-    darkPalette.setColor(QPalette::Highlight, QColor(42, 130, 218));
-    darkPalette.setColor(QPalette::HighlightedText, Qt::black);
-    darkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, disabledColor);
-
-    qApp->setPalette(darkPalette);
-}
-
-void MainWindow::setLightMode()
-{
-    FCT_IDENTIFICATION;
-
-    qApp->setPalette(this->style()->standardPalette());
-}
-
 void MainWindow::setupActivitiesMenu()
 {
     FCT_IDENTIFICATION;
@@ -1603,6 +1698,13 @@ void MainWindow::showAbout()
     QMessageBox::about(this, tr("About"), aboutText);
 }
 
+void MainWindow::showWhatsNew()
+{
+    FCT_IDENTIFICATION;
+
+    QDesktopServices::openUrl(QString("https://github.com/foldynl/QLog/releases/tag/v%0").arg(VERSION));
+}
+
 void MainWindow::showWikiHelp()
 {
     FCT_IDENTIFICATION;
