@@ -121,6 +121,7 @@ void QSOFilterDetail::addCondition(int fieldIdx, int operatorId, QString value)
     stacked->addWidget(createComboBox(Data::instance()->qsoCompleteEnum, value, condCount, sizePolicy));
     stacked->addWidget(createComboBox(Data::instance()->downloadStatusEnum, value, condCount, sizePolicy));
     stacked->addWidget(createComboBox(Data::instance()->morseKeyTypeEnum, value, condCount, sizePolicy));
+    stacked->addWidget(createComboBox(Data::instance()->eqslAgEnum, value, condCount, sizePolicy));
 
     conditionLayout->addWidget(stacked);
 
@@ -155,6 +156,8 @@ void QSOFilterDetail::addCondition(int fieldIdx, int operatorId, QString value)
             stacked->setCurrentIndex(10);
         else if ( this->isMorseKeyTypeField(fieldIndex))
             stacked->setCurrentIndex(11);
+        else if ( this->isEqslAgTypeField(fieldIndex))
+            stacked->setCurrentIndex(12);
         else
             stacked->setCurrentIndex(0);
     });
@@ -357,6 +360,14 @@ bool QSOFilterDetail::isMorseKeyTypeField(int index)
     return ret;
 }
 
+bool QSOFilterDetail::isEqslAgTypeField(int index)
+{
+    bool ret = ( index == LogbookModel::COLUMN_EQSL_AG );
+
+    qCDebug(function_parameters) << index << " return " << ret;
+    return ret;
+}
+
 QComboBox* QSOFilterDetail::createComboBox(const QMap<QString, QString> &mapping,
                                            const QString &value, const int identifier,
                                            const QSizePolicy &sizepolicy)
